@@ -173,11 +173,11 @@ def std_namer(name):
     new_dir_path = pathmaker(dir_path, 'old_logs')
     file_name = os.path.basename(name)
     file_number = 1
-    new_file_name = file_name.replace('.log', f"_{str(file_number)}.log")
+    new_file_name = file_name.split('.log')[0] + f"_{str(file_number)}.log"
     new_path = pathmaker(new_dir_path, new_file_name)
     while os.path.exists(new_path):
         file_number += 1
-        new_file_name = file_name.replace('.log', f"_{str(file_number)}.log")
+        new_file_name = file_name.split('.log')[0] + f"_{str(file_number)}.log"
         new_path = pathmaker(new_dir_path, new_file_name)
     return new_path
 
